@@ -1,52 +1,52 @@
+( cd usr/share/doc/HTML/da/kdesu ; rm -rf common )
+( cd usr/share/doc/HTML/da/kdesu ; ln -sf /usr/share/doc/HTML/da//common common )
 ( cd usr/share/doc/HTML/da/kppp ; rm -rf common )
 ( cd usr/share/doc/HTML/da/kppp ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kfilereplace ; rm -rf common )
-( cd usr/share/doc/HTML/da/kfilereplace ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/umbrello ; rm -rf common )
-( cd usr/share/doc/HTML/da/umbrello ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/telnet ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/telnet ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/sftp ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/sftp ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/mailto ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/mailto ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/nfs ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/nfs ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/finger ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/finger ; ln -sf /usr/share/doc/HTML/da//common common )
 ( cd usr/share/doc/HTML/da/kioslave/file ; rm -rf common )
 ( cd usr/share/doc/HTML/da/kioslave/file ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/nntp ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/nntp ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/floppy ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/floppy ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/ftp ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/ftp ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/data ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/data ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/tar ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/tar ; ln -sf /usr/share/doc/HTML/da//common common )
 ( cd usr/share/doc/HTML/da/kioslave/rlogin ; rm -rf common )
 ( cd usr/share/doc/HTML/da/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/fish ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/fish ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/info ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/info ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kioslave/ldap ; rm -rf common )
-( cd usr/share/doc/HTML/da/kioslave/ldap ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/tar ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/tar ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/finger ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/finger ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/floppy ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/floppy ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/mailto ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/mailto ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/sftp ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/sftp ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/telnet ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/telnet ; ln -sf /usr/share/doc/HTML/da//common common )
 ( cd usr/share/doc/HTML/da/kioslave/smtp ; rm -rf common )
 ( cd usr/share/doc/HTML/da/kioslave/smtp ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/nfs ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/nfs ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/ldap ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/ldap ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/info ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/info ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/nntp ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/nntp ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kioslave/ftp ; rm -rf common )
+( cd usr/share/doc/HTML/da/kioslave/ftp ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/ksysguard ; rm -rf common )
+( cd usr/share/doc/HTML/da/ksysguard ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/korganizer ; rm -rf common )
+( cd usr/share/doc/HTML/da/korganizer ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kmouth ; rm -rf common )
+( cd usr/share/doc/HTML/da/kmouth ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kfilereplace ; rm -rf common )
+( cd usr/share/doc/HTML/da/kfilereplace ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/khelpcenter/glossary ; rm -rf common )
+( cd usr/share/doc/HTML/da/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/umbrello ; rm -rf common )
+( cd usr/share/doc/HTML/da/umbrello ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/kommander ; rm -rf common )
+( cd usr/share/doc/HTML/da/kommander ; ln -sf /usr/share/doc/HTML/da//common common )
+( cd usr/share/doc/HTML/da/konsolekalendar ; rm -rf common )
+( cd usr/share/doc/HTML/da/konsolekalendar ; ln -sf /usr/share/doc/HTML/da//common common )
 ( cd usr/share/doc/HTML/da/konqueror ; rm -rf common )
 ( cd usr/share/doc/HTML/da/konqueror ; ln -sf /usr/share/doc/HTML/da//common common )
 ( cd usr/share/doc/HTML/da/klinkstatus ; rm -rf common )
 ( cd usr/share/doc/HTML/da/klinkstatus ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/ksysguard ; rm -rf common )
-( cd usr/share/doc/HTML/da/ksysguard ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kmouth ; rm -rf common )
-( cd usr/share/doc/HTML/da/kmouth ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kdesu ; rm -rf common )
-( cd usr/share/doc/HTML/da/kdesu ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/kommander ; rm -rf common )
-( cd usr/share/doc/HTML/da/kommander ; ln -sf /usr/share/doc/HTML/da//common common )
-( cd usr/share/doc/HTML/da/khelpcenter/glossary ; rm -rf common )
-( cd usr/share/doc/HTML/da/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/da//common common )
